@@ -1,6 +1,6 @@
 package Provision::Unix::VirtualOS::Linux::OpenVZ;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 use warnings;
 use strict;
@@ -13,18 +13,22 @@ use URI;
 use lib 'lib';
 use Provision::Unix::User;
 
-our ( $prov, $vos, $linux, $util );
-
 sub new {
     my $class = shift;
     my %p = validate( @_, { vos => { type => OBJECT } } );
 
-    $vos   = $p{vos};
-    $prov  = $vos->{prov};
-    $util  = $vos->{util};
-    $linux = $vos->{linux};
+    my $vos   = $p{vos};
+    my $prov  = $vos->{prov};
+    my $util  = $vos->{util};
+    my $linux = $vos->{linux};
 
-    my $self = bless { }, $class;
+    my $self = {
+        vos   => $vos,
+        prov  => $prov,
+        util  => $util,
+        linux => $linux,
+    };
+    bless $self, $class;
 
     $prov->audit("loaded P:U:V::Linux::OpenVZ");
 
@@ -36,6 +40,7 @@ sub new {
 sub create_virtualos {
 
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     $EUID == 0
         or $prov->error( "Create function requires root privileges." );
@@ -110,6 +115,7 @@ sub create_virtualos {
 sub destroy_virtualos {
 
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     $EUID == 0
         or $prov->error( "Destroy function requires root privileges." );
@@ -191,6 +197,7 @@ sub destroy_virtualos {
 sub start_virtualos {
 
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
     my $ctid = $vos->{name};
 
     $prov->audit("starting $ctid");
@@ -235,6 +242,7 @@ sub start_virtualos {
 sub stop_virtualos {
 
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     my $ctid = $vos->{name};
     
@@ -272,6 +280,7 @@ sub stop_virtualos {
 
 sub restart_virtualos {
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     $self->stop_virtualos()
         or
@@ -286,6 +295,7 @@ sub restart_virtualos {
 sub disable_virtualos {
 
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     my $ctid = $vos->{name};
     $prov->audit("disabling $ctid");
@@ -332,6 +342,7 @@ sub disable_virtualos {
 sub enable_virtualos {
 
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     my $ctid = $vos->{name};
     $prov->audit("enabling $ctid");
@@ -381,6 +392,7 @@ sub enable_virtualos {
 
 sub modify_virtualos {
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     $EUID == 0
         or $prov->error( "Modify function requires root privileges." );
@@ -393,11 +405,11 @@ sub modify_virtualos {
 
     return $prov->audit("\ttest mode early exit") if $vos->{test_mode};
 
+    $self->gen_config();
     $self->set_hostname()    if $vos->{hostname};
     $self->set_password()    if $vos->{password};
     $self->set_nameservers() if $vos->{nameservers};
-    $self->set_ips()         if $vos->{ip};
-    $self->gen_config();
+    $self->set_ips();
 
     $prov->audit("\tVE modified");
     $self->start_virtualos() or return;
@@ -405,8 +417,8 @@ sub modify_virtualos {
 }
 
 sub reinstall_virtualos {
-
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     $self->destroy_virtualos()
         or
@@ -419,14 +431,14 @@ sub reinstall_virtualos {
 }
 
 sub upgrade_virtualos {
-# delete after 9/15/09
+# delete after 11/01/09
     my $self = shift;
     return $self->modify_virtualos();
 };
 
 sub unmount_disk_image {
-
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     my $ctid = $vos->{name};
     $prov->audit("unmounting virtual $ctid");
@@ -465,10 +477,10 @@ sub unmount_disk_image {
 
 sub gen_config {
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 # most of this method was written by Max Vohra - 2009
 
-    my $ram  = $vos->{ram} or 
-        return $prov->error( "unable to determine RAM" );
+    my $ram  = $vos->{ram} or return $prov->error( "unable to determine RAM" );
     my $disk = $vos->{disk_size} or 
         return $prov->error( "unable to determine disk space" );
 
@@ -528,9 +540,10 @@ sub gen_config {
         ipt_TOS ipt_REDIRECT ) ) ];
     $config->{DEVICES} = [ "c:10:229:rw c:10:200:rw" ];
     $config->{ONBOOT}  = [ "yes" ]; 
+    my $time_dt = $prov->get_datetime_from_epoch();
     
     my $result = <<EO_MAX_CONFIG
-# This is a configuration file generated by Provision::Unix
+# This config file generated by Provision::Unix at $time_dt
 # The config parameters are: $ram RAM, and $disk disk space
 #
 EO_MAX_CONFIG
@@ -540,23 +553,16 @@ EO_MAX_CONFIG
         $result .= $var . '="' . join(":",@{$config->{$var}}) . "\"\n";
     };
 
-    my $name = $vos->{name};
     my $disk_root = $vos->{disk_root} || '/vz';
-    my $ip_string = join(' ', @{ $vos->{ip} } ) if $vos->{ip};
 
     $result .= <<EO_VE_CUSTOM
 \n# Provision::Unix Custom VE Additions
 VE_ROOT="$disk_root/root/\$VEID"
 VE_PRIVATE="$disk_root/private/\$VEID"
 OSTEMPLATE="$vos->{template}"
-ORIGIN_SAMPLE="$vos->{config}"
-HOSTNAME="$vos->{hostname}"
-IP_ADDRESS="$ip_string"
 EO_VE_CUSTOM
 ;
 
-    return $result;
-
     my $conf_file = $self->get_config();
 
 # install config file
@@ -565,6 +571,9 @@ EO_VE_CUSTOM
 };
 
 sub get_config {
+    my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
+
     my $ctid   = $vos->{name} or return;
     my $etc_dir = $prov->{etc_dir} || '/etc/vz/conf';
     my $config = "$etc_dir/$ctid.conf";
@@ -573,14 +582,16 @@ sub get_config {
 
 sub get_console {
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
+
     my $ctid = $vos->{name};
     my $cmd = $util->find_bin( bin => 'vzctl', debug => 0 );
     exec "$cmd enter $ctid";
 };
 
 sub get_disk_usage {
-    
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     $EUID == 0
         or return $prov->error( "Sorry, getting disk usage requires root.",
@@ -616,8 +627,8 @@ sub get_disk_usage {
 }
 
 sub get_os_template {
-    
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     my $config = $self->get_config();
     return if ! -f $config;
@@ -628,8 +639,9 @@ sub get_os_template {
 }
 
 sub get_status {
-
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
+
     my $name = $vos->{name};
     my %ve_info = ( name => $name );
     my $exists;
@@ -722,6 +734,8 @@ sub get_fs_root {
 
 sub get_ve_home {
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
+
     my $name = $vos->{name} || shift || die "missing VE name";
     my $disk_root = $vos->{disk_root} || '/vz';
     my $homedir = "$disk_root/private/$name";
@@ -730,6 +744,8 @@ sub get_ve_home {
 
 sub set_config {
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
+
     my $config = shift || _default_config();
     my $ctid = $vos->{name};
     my $config_file = $prov->{etc_dir} . "/$ctid.conf";
@@ -743,6 +759,7 @@ sub set_config {
 
 sub set_config_default {
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     my $config_file = $prov->{etc_dir} . "/ve-default.conf-sample";
     return if -f $config_file;
@@ -757,26 +774,30 @@ sub set_config_default {
 
 sub set_ips {
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
+    my $linux = $self->{linux};
+
+    my $ips = $vos->{ip};
 
     my (undef,undef,undef,$calling_sub) = caller(1);
     if ( $calling_sub eq 'modify_virtualos' ) {
         $prov->audit("using linux method to set ips");
         $linux->set_ips( 
-            ips     => $vos->{ip}, 
+            ips     => $ips, 
             fs_root => $self->get_fs_root(),
         );
         return;
     };
+
     my $cmd = $util->find_bin( bin => 'vzctl', debug => 0 );
     $cmd .= " set $vos->{name}";
 
-    my $ips = $vos->{ip};
     @$ips > 0
         or return $prov->error( 'set_ips called but no valid IPs were provided',
         fatal   => $vos->{fatal},
         );
 
-    foreach my $ip ( @{ $vos->{ip} } ) {
+    foreach my $ip ( @$ips ) {
         $cmd .= " --ipadd $ip";
     }
     $cmd .= " --save";
@@ -786,6 +807,7 @@ sub set_ips {
 
 sub set_password {
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     my $cmd = $util->find_bin( bin => 'vzctl', debug => 0 );
     $cmd .= " set $vos->{name}";
@@ -820,6 +842,7 @@ sub set_password {
 
 sub set_nameservers {
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     my $cmd = $util->find_bin( bin => 'vzctl', debug => 0 );
     $cmd .= " set $vos->{name}";
@@ -841,6 +864,7 @@ sub set_nameservers {
 
 sub set_hostname {
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     my $hostname = $vos->{hostname}
         or return $prov->error( 'no hostname defined',
@@ -870,6 +894,7 @@ sub pre_configure {
 
 sub is_mounted {
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     my %p = validate(
         @_,
@@ -891,6 +916,7 @@ sub is_mounted {
 
 sub is_present {
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     my %p = validate(
         @_,
@@ -912,6 +938,7 @@ sub is_present {
 
 sub is_running {
     my $self = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     my %p = validate(
         @_,
@@ -932,9 +959,9 @@ sub is_running {
 }
 
 sub _is_valid_template {
-
     my $self     = shift;
     my $template = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     my $template_dir = $self->{prov}{config}{ovz_template_dir} || '/vz/template/cache';
 
@@ -972,6 +999,7 @@ sub _is_valid_template {
 sub _is_valid_name {
     my $self = shift;
     my $name = shift;
+    my ($prov, $vos, $util) = ($self->{prov}, $self->{vos}, $self->{util});
 
     if ( $name !~ /^[0-9]+$/ ) {
         return $prov->error( "OpenVZ requires the name (VEID/CTID) to be numeric",
