@@ -431,7 +431,7 @@ sub modify_virtualos {
 }
 
 sub upgrade_virtualos {
-# temp placeholder, delete after 9/15/09
+# temp placeholder, delete after 11/01/09
     my $self = shift;
     return $self->modify_virtualos();
 };
@@ -1093,7 +1093,6 @@ sub set_password {
         if ( $self->is_running( debug => 0 ) ) {
             $self->stop_virtualos() or return;
             $i_stopped++;
-
         };
     
         my $r = $self->mount_disk_image();
@@ -1225,8 +1224,10 @@ sub gen_config {
     ($kernel) ||= </boot/vmlinuz-*xen>;
     ($ramdisk) ||= </boot/initrd-*xen.img>;
     my $cpu = $vos->{cpu} || 1;
+    my $time_dt = $prov->get_datetime_from_epoch();
 
     my $config = <<"EOCONF"
+# Config file generated by Provision::Unix at $time_dt
 kernel     = '$kernel'
 ramdisk    = '$ramdisk'
 memory     = $ram
@@ -1241,7 +1242,7 @@ root       = '/dev/sda1 ro'
 extra      = 'console=xvc0'
 vcpus      = $cpu
 EOCONF
-        ;
+;
 
     # These can also be set in the config file.
     #console    =
